@@ -20,7 +20,7 @@ from .util import Print, VERBOSITY, Preproc as Pp
 from functools import reduce
 from six.moves import xrange
 
-__version__ = "0.5.0"
+__version__ = "0.5.2"
 
 ENCODING = "utf-8"
 
@@ -528,7 +528,7 @@ class SS3:
 
         If category name doesn't exist, creates a new one.
         """
-        if type(name) is str:
+        if isinstance(name, str):
             name = name.lower()
         try:
             return self.__categories_index__[name]
@@ -1077,7 +1077,7 @@ class SS3:
         :rtype: int
         """
         try:
-            if type(name) is str:
+            if isinstance(name, str):
                 name = name.lower()
             return self.__categories_index__[name]
         except KeyError:
@@ -1094,7 +1094,7 @@ class SS3:
         :rtype: str
         """
         try:
-            if type(index) == list:
+            if isinstance(index, list):
                 index = index[0]
             return self.__categories__[index][NAME]
         except IndexError:
@@ -2044,6 +2044,8 @@ class SS3:
         cats = sorted(list(set(y_train)))
         stime = time()
 
+        x_train, y_train = list(x_train), list(y_train)
+
         x_train = [
             "".join([
                 x_train[i]
@@ -2092,6 +2094,7 @@ class SS3:
         if not self.__categories__:
             raise EmptyModelError
 
+        x_test = list(x_test)
         classify = self.classify
         return [
             classify(x, sort=False)
@@ -2151,7 +2154,7 @@ class SS3:
         stime = time()
         Print.info("about to start classifying test documents", offset=1)
         classify = self.classify_label if not multilabel else self.classify_multilabel
-
+        x_test = list(x_test)
         y_pred = [
             classify(doc, def_cat=def_cat, labels=labels, prep=prep)
             for doc in tqdm(x_test, desc="Classification",
